camelot.camelot.model.memento.Create

Package camelot :: Package camelot :: Package model :: Module memento :: Class Create |
[hide private]
[frames] | no frames]

# Class Create

source code

Marks the creation of an object

Nested Classes | [hide private]
| Admin

Instance Methods | [hide private]
description(self) | source code

Class Variables | [hide private]
Inherited from `Memento`: `creation_date`, `model`, `person`, `primary_key`

Method Details | [hide private]

### description(self) | source code
Decorators: `@property` Overrides: description